==> byways-2.0.1.tgz: package/contents/byway/13754.md <==
---
template: byway.jade
id: "13754"
name: "Woodward Avenue (M-1) - Automotive Heritage Trail"
distance: "27"
duration: One hour to visit the entire byway or three to five days to enjoy the attractions
description: "If  Broadway = Theater and Rodeo Drive = High Fashion and Jewelry, then Woodward = the Automobile. The Motor City, and in particular, Woodward Avenue, put the world on wheels. America's automobile heritage is represented along this byway in famed industrial complexes, office buildings, residential mansions, world-renowned museums, and cultural institutions."
contact: "**[Detroit Metro Convention and Visitors Bureau](http://www.visitdetroit.com)**  \r\n 313-202-1800  \r\n 1-800-DETROIT (338-7648)  \r\n [Send E-mail](mailto:VIC@visitdetroit.com )  \r\n\r\n"
path: "qhjaGzqzyNuIjGiDtB}DAO^ExCIRqJlHwJ`HaWhOwnAnt@}HtFaIxEaKdFeMzHsRvKeOxJqn@b^oiElgC{c@bXwEjCkYvP[LU?sBhAsb@xWszBlrAiHhFsUtNgDjB_C`AwZrQyKzGyY|Psh@v[_N~HeIhF}F`FkLdLyZxX{FdFm@b@eOdNgn@bk@iu@`s@kXzW{BlBSNys@rr@u~CzxCcCrBkGtEmK|GoHzDoCjA}UtIyBfAkKfHyArAcD~DoBdDcLxUkClDaCdCcAx@yMrIc`@bVaGnE_rBjkB_GzEgKlGsDdCiBxA}CnCgClCoDpEaH`KcCxCsCxCqmArhAqkAngA}IxIoe@rb@sEpEeBhBaGlG}Ab@oP`@mEK}Ny@aA?{Hr@wHJ"
websites: 
  - url: "http://www.cranbrook.edu/"
    name: Cranbrook Education
  - url: "http://www.fws.gov/refuges/profiles/index.cfm?id=31521"
    name: Detroit River International Wildlife Refuge
  - url: "http://www.historicroads.org/"
    name: Historic Roads
  - url: "http://www.midwestconnection.com/Lighthouses/StClairLH.htm"
    name: "Lighthouses: St. Clair Region"
  - url: "http://www.motorcities.org/"
    name: MotorCities National Heritage Area
  - url: "http://www.michigan.org/"
    name: Pure Michigan Travel
  - url: "http://www.visitdetroit.com/"
    name: Visit Detroit
  - url: "http://www.woodwardavenue.us/"
    name: Woodward Avenue
  - url: "http://www.woodwardavenue.org/Tour/Woodward+Events-3.html"
    name: Woodward Avenue Calendar of Events
  - url: "http://woodwardstore.org"
    name: Woodward Store
designations: 
  - "All-American Road"
  - National Scenic Byway
  - Michigan Heritage Route
  - Automobile National Heritage Area
states: 
  - MI
ll: 
  - -83.04429599999997
  - 42.32857900000005
bounds: 
  - - -83.28871200000003
    - 42.32857900000005
  - - -83.04429599999997
    - 42.639511000000084

---

If  Broadway = Theater and Rodeo Drive = High Fashion and Jewelry, then Woodward = the Automobile. The Motor City, and in particular, Woodward Avenue, put the world on wheels. America's automobile heritage is represented along this byway in famed industrial complexes, office buildings, residential mansions, world-renowned museums, and cultural institutions.

==> byways-2.2.2.tgz: package/contents/byway/13754.md <==
---
template: byway.jade
id: "13754"
name: "Woodward Avenue (M-1) Automotive Heritage Trail"
distance: "27"
duration: One hour to visit the entire byway or three to five days to enjoy the attractions
description: "If  Broadway = Theater and Rodeo Drive = High Fashion and Jewelry, then Woodward = the Automobile. The Motor City, and in particular, Woodward Avenue, put the world on wheels. America's automobile heritage is represented along this byway in famed industrial complexes, office buildings, residential mansions, world-renowned museums, and cultural institutions."
contact: "**[Detroit Metro Convention and Visitors Bureau](http://www.visitdetroit.com)**  \r\n 313-202-1800  \r\n 1-800-DETROIT (338-7648)  \r\n [Send E-mail](mailto:VIC@visitdetroit.com )  \r\n\r\n"
path: "qhjaGzqzyNuIjGiDtB}DAO^ExCIRqJlHwJ`HaWhOwnAnt@}HtFaIxEaKdFeMzHsRvKeOxJqn@b^oiElgC{c@bXwEjCkYvP[LU?sBhAsb@xWszBlrAiHhFsUtNgDjB_C`AwZrQyKzGyY|Psh@v[_N~HeIhF}F`FkLdLyZxX{FdFm@b@eOdNgn@bk@iu@`s@kXzW{BlBSNys@rr@u~CzxCcCrBkGtEmK|GoHzDoCjA}UtIyBfAkKfHyArAcD~DoBdDcLxUkClDaCdCcAx@yMrIc`@bVaGnE_rBjkB_GzEgKlGsDdCiBxA}CnCgClCoDpEaH`KcCxCsCxCqmArhAqkAngA}IxIoe@rb@sEpEeBhBaGlG}Ab@oP`@mEK}Ny@aA?{Hr@wHJ"
websites:
  - url: "http://www.cranbrook.edu/"
    name: Cranbrook Education
  - url: "http://www.fws.gov/refuges/profiles/index.cfm?id=31521"
    name: Detroit River International Wildlife Refuge
  - url: "https://www.motorcities.org/things-to-see-in-detroit"
    name: MotorCities National Heritage Area
  - url: "http://www.michigan.org/"
    name: Pure Michigan Travel
  - url: "https://visitdetroit.com/explore-detroit-block-by-block-woodward-avenue-edition/"
    name: Visit Detroit
  - url: "http://www.woodwardavenue.org"
    name: Woodward Avenue Action Association
designations:
  - "All-American Road"
  - National Scenic Byway
  - Michigan Heritage Route
  - Automobile National Heritage Area
states:
  - MI
ll:
  - -83.04429599999997
  - 42.32857900000005
bounds:
  - - -83.28871200000003
    - 42.32857900000005
  - - -83.04429599999997
    - 42.639511000000084

---

If  Broadway = Theater and Rodeo Drive = High Fashion and Jewelry, then Woodward = the Automobile. The Motor City, and in particular, Woodward Avenue, put the world on wheels. America's automobile heritage is represented along this byway in famed industrial complexes, office buildings, residential mansions, world-renowned museums, and cultural institutions.
